@@ -197,7 +197,7 @@ sub _checkContent {
         my $handler = $deprecated->{$old};
 
         # notify user of deprecation
-        print STDERR "the '$old' option is deprecated, $handler->{message}\n";
+        warn "the '$old' option is deprecated, $handler->{message}\n";
 
         # transfer the value to the new option, if possible
         if ($handler->{new}) {
@@ -234,6 +234,11 @@ sub _checkContent {
         $self->{logger} .= ',File';
     }
 
+    # ca-cert-file and ca-cert-dir are antagonists
+    if ($self->{'ca-cert-file'} && $self->{'ca-cert-dir'}) {
+        die "use either 'ca-cert-file' or 'ca-cert-dir' option, not both\n";
+    }
+
     # multi-values options, the default separator is a ','
     foreach my $option (qw/
             logger
@@ -287,3 +292,5 @@ the configuration directory.
 =item I<options>
 
 additional options override.
+
+=back
